@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "claude-code" "0.8.1"
+(define-package "claude-code" "20250919.1908"
   "Run Claude Code sessions."
   '((emacs         "28.1")
     (projectile    "2.5.0")
@@ -7,6 +7,6 @@
     (transient     "0.4.0")
     (markdown-mode "2.5"))
   :url "https://github.com/yuya373/claude-code-emacs"
-  :commit "0c3019819ce870619d4425cebf7286e03e531c66"
-  :revdesc "0c3019819ce8"
+  :commit "56cccf63709b305bfd74ab72f20bd9d3b12f7d09"
+  :revdesc "56cccf63709b"
   :keywords '("tools" "convenience"))
